//-----------------------------------------------------------------------------
// Project            	GeometryKit
// Class		G3DTuple2f
// Creator            	Philippe C.D. Robert
// Maintainer         	Philippe C.D. Robert
// Creation Date      	Thu Sep  9 11:05:08 CEST 1999
//
// Copyright (c) Philippe C.D. Robert
//
// The GeometryKit is free software; you can redistribute it and/or modify it 
// under the terms of the GNU LGPL Version 2 as published by the Free 
// Software Foundation
//
// $Id: G3DTuple2f.h,v 1.5 2001/01/05 20:50:49 robert Exp $
//-----------------------------------------------------------------------------

#ifndef __G3DTuple2f_h_INCLUDE
#define __G3DTuple2f_h_INCLUDE

#import <Foundation/Foundation.h>

@interface G3DTuple2f : NSObject <NSCoding, NSCopying>
{
  float tuple[2];
}

//-----------------------------------------------------------------------------
// Class methods
//-----------------------------------------------------------------------------

+ (void)initialize;

+ (G3DTuple2f *)tuple2f;
+ (G3DTuple2f *)tuple2fWithElements:(float *)vals;
+ (G3DTuple2f *)tuple2fWithX:(float)x y:(float)y;
+ (G3DTuple2f *)tuple2fWithTuple2f:(G3DTuple2f *)aTuple;

//-----------------------------------------------------------------------------
// init and free
//-----------------------------------------------------------------------------

- (id)init;
  // Initialises a new tuple by invoking initWithElements

- (id)initWithElements:(float *)vals;

- (id)initWithX:(float)x y:(float)y;

- (id)initWithTuple:(G3DTuple2f *)aTuple;
  // Initialises a new tuple by invoking initWithElements

//-----------------------------------------------------------------------------
// Math
//-----------------------------------------------------------------------------

- (void)absolute;

- (void)clamp;
- (void)clampLow:(float)low high:(float)high;

- (void)addTuple2f:(G3DTuple2f *)aTuple;
- (void)subTuple2f:(G3DTuple2f *)aTuple;

- (void)multiplyBy:(float)aScalar;
- (void)divideBy:(float)aScalar;

- (void)interpolateBetween:(G3DTuple2f *)first and:(G3DTuple2f *)second factor:(float)factor;
// (1-factor)*first + factor*second

- (void)negate;

- (BOOL)isEqualToTuple:(id)anObj;

//-----------------------------------------------------------------------------
// Accessing
//-----------------------------------------------------------------------------

- (float *)elements;
- (void)setElements:(float *)values;
- (void)getElements:(float *)values;

- (float)x;
- (void)setX:(float)x;

- (float)y;
- (void)setX:(float)y;

- (void)setValuesWithTuple:(G3DTuple2f *)aTuple;

- (NSString *)description;

//-----------------------------------------------------------------------------
// NSCoding
//-----------------------------------------------------------------------------

- (void)encodeWithCoder:(NSCoder *)aCoder;
- (id)initWithCoder:(NSCoder *)aCoder;

//-----------------------------------------------------------------------------
// NSCopying
//-----------------------------------------------------------------------------

- (id)copyWithZone:(NSZone *)zone;

@end

extern NSString *G3DTuple2fException;

#endif




